@@ -3,14 +3,9 @@ package App::paperback;
 use v5.10;
 use strict;
 # use warnings;
-our $VERSION = "v1.03";
+our $VERSION = "v1.04";
 
-use Exporter;
-our @ISA    = qw(Exporter);
-our @EXPORT = qw(openInputFile openOutputFile newPageInOutputFile
-	copyPageFromInputToOutput closeInputFile closeOutputFile);
-
-my ($GformNr, $GinFile, $GpageObjNr, $Groot, $Gpos, $GobjNr, $Gstream, $GoWid, $GoHei);
+my ($GinFile, $GpageObjNr, $Groot, $Gpos, $GobjNr, $Gstream, $GoWid, $GoHei);
 my (@Gkids, @Gcounts, @GformBox, @Gobject, @Gparents, @Gto_be_created);
 my (%Gold, %Gresources, %GpageXObject, %GoldObject);
 
@@ -110,6 +105,8 @@ ANSI normalised (US) page sizes:
   Before that, input pages will be reordered and reoriented so as to 
   produce a final PDF fit for duplex 'long-edge-flip' printing.
 
+For further details, please try 'perldoc paperback'.
+
 ${sayVersion}
 END_MESSAGE
 
@@ -119,7 +116,7 @@ END_MESSAGE
     if $input =~ "^-h\$" or $input =~ "^--help\$";
   do {print STDERR "${sayVersion}\n" and exit}
     if $input =~ "^-v\$" or $input =~ "^--version\$";
-  die "[!] File '$input' can't be found or read.\n"
+  die "[!] File '$input' can't be found or sysread.\n"
     unless -r $input;
   ($num_pag_input, $pgSizeInput) = openInputFile($input);
   die "[!] File '$input' is not a valid v1.4 PDF file.\n"
@@ -198,8 +195,10 @@ sub copyPageFromInputToOutput {
   my $y          = $param->{'y'}      or 0;
   my $rotate     = $param->{'rotate'} or 0;
 
-  ++$GformNr;
-  my $name = "Fm${GformNr}";
+  state $formNr; # Este uso de "state" requiere v5.10 (que salió en 2007)
+  ++$formNr;
+
+  my $name = "Fm${formNr}";
   my $refNr = getPage( $pagenumber );
   die "[!] Page ${pagenumber} in ${GinFile} can't be used. Concatenate streams!" 
   	if !defined $refNr;
@@ -483,6 +482,7 @@ sub getObject {
 
   sysseek $IN_FILE, $offs, 0;
   sysread $IN_FILE, $buf, $size;
+
   return $buf;
 }
 
